Module preamble

Module preamble 

Entry-point re-exports for the layout manager and frame configurator.

Most applications use CotisLayoutManager as the LayoutManager type parameter on CotisApp and interact with elements each frame through CotisLayoutRun via the standard Cotis configuring traits (see crate::cotis_traits).

Structs

CotisLayoutManager
Owns the layout tree, viewport size, text measurer, and post-frame element cache.
CotisLayoutRun
Per-frame element tree configurator returned by LayoutManager::begin_frame.

Traits

TextConfigurable
A configuration that can spawn transparent synthetic children used to lay out text.